.. currentmodule:: abjad.tools.scoretools

fill_measures_in_expr_with_minimal_number_of_notes
==================================================

.. autofunction:: fill_measures_in_expr_with_minimal_number_of_notes
